import { registerExtension } from 'vscode/extensions';

const manifest = {"name":"vscode-postgres","displayName":"PostgreSQL","description":"PostgreSQL Management Tool","version":"1.4.3","publisher":"ckolkman","license":"MIT","repository":{"type":"git","url":"https://github.com/Borvik/vscode-postgres.git"},"engines":{"vscode":"^1.63.0"},"categories":["Other"],"activationEvents":["*"],"contributes":{"languages":[{"id":"postgres","extensions":[".pgsql",".psql"],"aliases":["Postgres"],"configuration":"./language-configuration.json"}],"grammars":[{"language":"postgres","scopeName":"source.pgsql","path":"./syntaxes/pgsql.tmLanguage"}],"configuration":{"type":"object","title":"PostgreSQL","properties":{"vscode-postgres.defaultConnection":{"type":"string","default":"","description":"The default connection to use"},"vscode-postgres.defaultDatabase":{"type":"string","default":"","description":"The default database on the default connection to use"},"vscode-postgres.showExplorer":{"type":"boolean","default":true,"description":"Show or hide the database explorer."},"vscode-postgres.prettyPrintJSONfields":{"type":"boolean","default":false,"description":"Turns on/off pretty printing of JSON fields"},"vscode-postgres.setConnectionFromExplorer":{"type":"string","enum":["always","ifunset","never"],"default":"always","description":"Controls whether selecting a database in explorer changes the current editor's connection"},"vscode-postgres.tableColumnSortOrder":{"type":"string","enum":["db-order","alpha","reverse-alpha"],"default":"db-order","description":"Controls the order of the columns in the database explorer. Default is db-order which orders the columns as the were added to the table (how postgres reports them)"},"vscode-postgres.intervalFormat":{"type":"string","enum":["iso_8601","humanize","succinct"],"default":"iso_8601","description":"Controls the display format for `interval` columns. Default is the iso_8601 standard which does not cover milliseconds."},"vscode-postgres.virtualFolders":{"type":"array","default":["functions"],"description":"Controls virtual folders that are shown under schema. Currently only functions are supported."}}},"submenus":[{"id":"postgres.select","label":"Select..."}],"viewsContainers":{"activitybar":[{"id":"postgres-explorer","title":"PostgreSQL Explorer","icon":"resources/postgres-explorer.svg"}]}},"scripts":{"vscode:prepublish":"npm run build-preview && npm run compile","compile":"tsc -p ./","watch":"npm run build-preview-dev && tsc -watch -p ./","build-preview-dev":"npx webpack --mode development","build-preview":"npx webpack --mode production"},"devDependencies":{"@types/mocha":"^2.2.42","@types/node":"^12.12.68","@types/pg":"^7.14.4","@types/uuid":"^8.3.0","@types/vscode":"^1.57.0","ts-loader":"^8.0.4","typescript":"^4.3.2","webpack":"^5.38.1","webpack-cli":"^4.7.2"},"dependencies":{"csv-stringify":"^5.6.2","easyxml":"^2.0.1","pg":"^8.6.0","postgres-array":"^3.0.2","uuid":"^8.3.2","vscode-languageclient":"^7.0.0","vscode-languageserver":"^7.0.0","vscode-languageserver-textdocument":"^1.0.1"}};

const { registerFileUrl, whenReady } = registerExtension(manifest);


registerFileUrl('syntaxes/pgsql.tmLanguage', new URL('../assets/ckolkman.vscode-postgres-1.4.3.vsix/pgsql.tmLanguage', import.meta.url).href);

registerFileUrl('language-configuration.json', new URL('../assets/ckolkman.vscode-postgres-1.4.3.vsix/language-configuration.json', import.meta.url).href, 'application/json');

registerFileUrl('resources/postgres-explorer.svg', new URL('../assets/ckolkman.vscode-postgres-1.4.3.vsix/postgres-explorer.svg', import.meta.url).href, 'image/svg+xml');

registerFileUrl('package.json', new URL('../assets/ckolkman.vscode-postgres-1.4.3.vsix/package.json', import.meta.url).href, 'application/json');

export { whenReady };
