import { errorHandler, createConfiguredEditor, createModelReference as createModelReference$1 } from 'vscode/monaco';
import { initialize, editorOpenHandlerRegistry } from './services.js';
import './languages/index.js';
import './theme/index.js';
import './worker.js';
import setup from './editor/index.js';

// see https://github.com/microsoft/monaco-editor/issues/4378
// eslint-disable-next-line @typescript-eslint/no-explicit-any
global.vscode = {
    process: false
};
errorHandler.setUnexpectedErrorHandler(error => {
    console.warn('Unexpected error', error);
});
let initialized = false;
const initializePromise = initialize().then(() => { initialized = true; });
function createEditor(domElement, options) {
    if (!initialized) {
        throw new Error('Monaco not initialized');
    }
    const editor = createConfiguredEditor(domElement, options);
    setup(editor);
    return editor;
}
async function createModelReference(resource, content) {
    await initializePromise;
    return createModelReference$1(resource, content);
}
function registerEditorOpenHandler(handler) {
    return editorOpenHandlerRegistry.registerEditorOpenHandler(handler);
}

export { createEditor, createModelReference, initializePromise, registerEditorOpenHandler };
